.. highlight:: shell

============
Installation
============


Stable release
--------------

To install ``pydnameth``, run this command in your terminal::

    $ pip install -U pydnameth

This is the preferred method to install pydnameth, as it will always install the most recent stable release.

If you don't have `pip`_ installed, this `Python installation guide`_ can guide
you through the process.

.. _pip: https://pip.pypa.io
.. _Python installation guide: http://docs.python-guide.org/en/latest/starting/installation/

If you want to save figures locally as ``.pdf`` and ``.png`` run the command::

    $ conda install -c plotly plotly-orca psutil

From sources
------------

The sources for pydnameth can be downloaded from the `GitHub repo`_.

You can either clone the public repository::

    $ git clone git://github.com/AaronBlare/pydnameth

Once you have a copy of the source, you can install it with::

    $ python setup.py install


.. _GitHub repo: https://github.com/AaronBlare/pydnameth
.. _tarball: https://github.com/AaronBlare/pydnameth/tarball/master
